#ifndef EXTCONF_H
#define EXTCONF_H
#define HAVE_PQCONNECTIONUSEDPASSWORD 1
#define HAVE_PQISTHREADSAFE 1
#define HAVE_PQPREPARE 1
#define HAVE_PQEXECPARAMS 1
#define HAVE_PQESCAPESTRING 1
#define HAVE_PQESCAPESTRINGCONN 1
#define HAVE_PQESCAPELITERAL 1
#define HAVE_PQESCAPEIDENTIFIER 1
#define HAVE_PQGETCANCEL 1
#define HAVE_LO_CREATE 1
#define HAVE_PG_ENCODING_TO_CHAR 1
#define HAVE_PG_CHAR_TO_ENCODING 1
#define HAVE_PQSETCLIENTENCODING 1
#define HAVE_PQLIBVERSION 1
#define HAVE_PQPING 1
#define HAVE_PQSETSINGLEROWMODE 1
#define HAVE_RB_ENCDB_ALIAS 1
#define HAVE_RB_THREAD_CALL_WITHOUT_GVL 1
#define HAVE_RB_THREAD_CALL_WITH_GVL 1
#define HAVE_RB_THREAD_FD_SELECT 1
#define HAVE_CONST_PGRES_COPY_BOTH 1
#define HAVE_CONST_PGRES_SINGLE_TUPLE 1
#define HAVE_STRUCT_PGNOTIFY_EXTRA 1
#define HAVE_ST_EXTRA 1
#define HAVE_ST_NOTIFY_EXTRA 1
#define HAVE_UNISTD_H 1
#define HAVE_RUBY_ST_H 1
#endif
